@@ -323,58 +323,34 @@ static void
 create_docinfo_dialog (GeditDocinfoPlugin *plugin)
 {
 	GeditDocinfoPluginPrivate *priv;
-	gchar *data_dir;
-	gchar *ui_file;
-	GtkWidget *content;
-	GtkWidget *error_widget;
-	gboolean ret;
+	GtkBuilder *builder;
 
 	gedit_debug (DEBUG_PLUGINS);
 
 	priv = plugin->priv;
 
-	data_dir = peas_extension_base_get_data_dir (PEAS_EXTENSION_BASE (plugin));
-
-	ui_file = g_build_filename (data_dir, "gedit-docinfo-plugin.ui", NULL);
-	ret = gedit_utils_get_ui_objects (ui_file,
-					  NULL,
-					  &error_widget,
-					  "dialog", &priv->dialog,
-					  "docinfo_dialog_content", &content,
-					  "file_name_label", &priv->file_name_label,
-					  "words_label", &priv->words_label,
-					  "bytes_label", &priv->bytes_label,
-					  "lines_label", &priv->lines_label,
-					  "chars_label", &priv->chars_label,
-					  "chars_ns_label", &priv->chars_ns_label,
-					  "document_label", &priv->document_label,
-					  "document_words_label", &priv->document_words_label,
-					  "document_bytes_label", &priv->document_bytes_label,
-					  "document_lines_label", &priv->document_lines_label,
-					  "document_chars_label", &priv->document_chars_label,
-					  "document_chars_ns_label", &priv->document_chars_ns_label,
-					  "selection_label", &priv->selection_label,
-					  "selected_words_label", &priv->selected_words_label,
-					  "selected_bytes_label", &priv->selected_bytes_label,
-					  "selected_lines_label", &priv->selected_lines_label,
-					  "selected_chars_label", &priv->selected_chars_label,
-					  "selected_chars_ns_label", &priv->selected_chars_ns_label,
-					  NULL);
-
-	g_free (data_dir);
-	g_free (ui_file);
-
-	if (!ret)
-	{
-		const gchar *err_message;
-
-		err_message = gtk_label_get_label (GTK_LABEL (error_widget));
-		gedit_warning (GTK_WINDOW (priv->window), "%s", err_message);
-
-		gtk_widget_destroy (error_widget);
-
-		return;
-	}
+	builder = gtk_builder_new ();
+	gtk_builder_add_from_resource (builder, "/org/gnome/gedit/plugins/docinfo/ui/gedit-docinfo-plugin.ui", NULL);
+	priv->dialog = GTK_WIDGET (gtk_builder_get_object (builder, "dialog"));
+	priv->file_name_label = GTK_WIDGET (gtk_builder_get_object (builder, "file_name_label"));
+	priv->words_label = GTK_WIDGET (gtk_builder_get_object (builder, "words_label"));
+	priv->bytes_label = GTK_WIDGET (gtk_builder_get_object (builder, "bytes_label"));
+	priv->lines_label = GTK_WIDGET (gtk_builder_get_object (builder, "lines_label"));
+	priv->chars_label = GTK_WIDGET (gtk_builder_get_object (builder, "chars_label"));
+	priv->chars_ns_label = GTK_WIDGET (gtk_builder_get_object (builder, "chars_ns_label"));
+	priv->document_label = GTK_WIDGET (gtk_builder_get_object (builder, "document_label"));
+	priv->document_words_label = GTK_WIDGET (gtk_builder_get_object (builder, "document_words_label"));
+	priv->document_bytes_label = GTK_WIDGET (gtk_builder_get_object (builder, "document_bytes_label"));
+	priv->document_lines_label = GTK_WIDGET (gtk_builder_get_object (builder, "document_lines_label"));
+	priv->document_chars_label = GTK_WIDGET (gtk_builder_get_object (builder, "document_chars_label"));
+	priv->document_chars_ns_label = GTK_WIDGET (gtk_builder_get_object (builder, "document_chars_ns_label"));
+	priv->selection_label = GTK_WIDGET (gtk_builder_get_object (builder, "selection_label"));
+	priv->selected_words_label = GTK_WIDGET (gtk_builder_get_object (builder, "selected_words_label"));
+	priv->selected_bytes_label = GTK_WIDGET (gtk_builder_get_object (builder, "selected_bytes_label"));
+	priv->selected_lines_label = GTK_WIDGET (gtk_builder_get_object (builder, "selected_lines_label"));
+	priv->selected_chars_label = GTK_WIDGET (gtk_builder_get_object (builder, "selected_chars_label"));
+	priv->selected_chars_ns_label = GTK_WIDGET (gtk_builder_get_object (builder, "selected_chars_ns_label"));
+	g_object_unref (builder);
 
 	gtk_dialog_set_default_response (GTK_DIALOG (priv->dialog),
 					 GTK_RESPONSE_OK);
